@@ -5,12 +5,6 @@
 #' a tidy data set made of collocating words.
 #'
 #' @param x A \code{\link[tm]{DocumentTermMatrix}}/\code{\link[tm]{TermDocumentMatrix}}.
-#' @param as.tibble logical.  If \code{TRUE} the output class will be set to a
-#' \pkg{tibble}, otherwise a \code{\link[data.table]{data.table}}.  Default
-#' checks \code{getOption("tibble.out")} as a logical.  If this is \code{NULL}
-#' the default \code{\link[textshape]{tibble_output}} will set \code{as.tibble}
-#' to \code{TRUE} if \pkg{dplyr} is loaded.  Otherwise, the output will be a
-#' \code{\link[data.table]{data.table}}.
 #' @param \ldots Ignored.
 #' @return Returns a tidied data.frame.
 #' @rdname tidy_colo_dtm
@@ -42,40 +36,34 @@
 #'         scale_fill_gradient(low= 'white', high = 'red') +
 #'         theme(axis.text.x = element_text(angle = 45, hjust = 1))
 #' }
-tidy_colo_tdm <- function(x, as.tibble = tibble_output(), ...){
+tidy_colo_tdm <- function(x, ...){
 
     term_1 <- NULL
 
     x <- slam::as.simple_triplet_matrix(slam::tcrossprod_simple_triplet_matrix(x, y = NULL))
 
-    if_tibble(
-        data.table::data.table(
-            term_1 = x[['dimnames']][['Terms']][x[['i']]],
-            term_2 = x[['dimnames']][['Terms']][x[['j']]],
-            n = x[['v']]
-        )[order(term_1), ],
-        as.tibble = as.tibble
-    )
+    data.table::data.table(
+        term_1 = x[['dimnames']][['Terms']][x[['i']]],
+        term_2 = x[['dimnames']][['Terms']][x[['j']]],
+        n = x[['v']]
+    )[order(term_1), ]
 }
 
 
 
 #' @rdname tidy_colo_dtm
 #' @export
-tidy_colo_dtm <- function(x, as.tibble = tibble_output(), ...){
+tidy_colo_dtm <- function(x, ...){
 
     term_1 <- NULL
 
     x <- slam::as.simple_triplet_matrix(slam::crossprod_simple_triplet_matrix(x, y = NULL))
 
-    if_tibble(
-        data.table::data.table(
-            term_1 = x[['dimnames']][['Terms']][x[['i']]],
-            term_2 = x[['dimnames']][['Terms']][x[['j']]],
-            n = x[['v']]
-        )[order(term_1), ],
-        as.tibble = as.tibble
-    )
+    data.table::data.table(
+        term_1 = x[['dimnames']][['Terms']][x[['i']]],
+        term_2 = x[['dimnames']][['Terms']][x[['j']]],
+        n = x[['v']]
+    )[order(term_1), ]
 }
 
 
