@@ -7,12 +7,6 @@
 #'
 #'
 #' @param x A \code{\link[tm]{DocumentTermMatrix}}/\code{\link[tm]{TermDocumentMatrix}}.
-#' @param as.tibble logical.  If \code{TRUE} the output class will be set to a
-#' \pkg{tibble}, otherwise a \code{\link[data.table]{data.table}}.  Default
-#' checks \code{getOption("tibble.out")} as a logical.  If this is \code{NULL}
-#' the default \code{\link[textshape]{tibble_output}} will set \code{as.tibble}
-#' to \code{TRUE} if \pkg{dplyr} is loaded.  Otherwise, the output will be a
-#' \code{\link[data.table]{data.table}}.
 #' @param \ldots ignored.
 #' @return Returns a tidied data.frame.
 #' @rdname tidy_dtm
@@ -52,38 +46,32 @@
 #'         facet_wrap(~time, ncol=2, scales = 'free_y') +
 #'         scale_y_discrete(labels = function(x) gsub("__.+$", "", x))
 #' }
-tidy_dtm <- function(x, as.tibble = tibble_output(), ...){
+tidy_dtm <- function(x, ...){
 
     doc <- NULL
 
-    if_tibble(
-        data.table::data.table(
-            doc = x[['dimnames']][['Docs']][x[['i']]],
-            term = x[['dimnames']][['Terms']][x[['j']]],
-            n = x[['v']],
-            i = x[['i']],
-            j = x[['j']]
-        )[order(doc), ],
-        as.tibble = as.tibble
-    )
+    data.table::data.table(
+        doc = x[['dimnames']][['Docs']][x[['i']]],
+        term = x[['dimnames']][['Terms']][x[['j']]],
+        n = x[['v']],
+        i = x[['i']],
+        j = x[['j']]
+    )[order(doc), ]
 }
 
 
 
 #' @rdname tidy_dtm
 #' @export
-tidy_tdm <- function(x, as.tibble = tibble_output(), ...){
+tidy_tdm <- function(x, ...){
 
     doc <- NULL
 
-    if_tibble(
-        data.table::data.table(
-            doc = x[['dimnames']][['Docs']][x[['j']]],
-            term = x[['dimnames']][['Terms']][x[['i']]],
-            n = x[['v']],
-            i = x[['j']],
-            j = x[['i']]
-        )[order(doc), ],
-        as.tibble = as.tibble
-    )
+    data.table::data.table(
+        doc = x[['dimnames']][['Docs']][x[['j']]],
+        term = x[['dimnames']][['Terms']][x[['i']]],
+        n = x[['v']],
+        i = x[['j']],
+        j = x[['i']]
+    )[order(doc), ]
 }
