@@ -1,4 +1,4 @@
-#' Tidy a List of Named Dataframes or Vectors
+#' Tidy a List of Named Dataframes or Named Vectors or Vectors
 #'
 #' \code{\link[base]{rbind}} a named \code{\link[base]{list}} of
 #' \code{\link[base]{data.frame}}s or \code{\link[base]{vector}}s to
@@ -9,13 +9,10 @@
 #' \code{\link[base]{data.frame}}s or \code{\link[base]{vector}}.
 #' @param id.name The name to use for the column created from the \code{\link[base]{list}}.
 #' @param content.name The name to use for the column created from the \code{\link[base]{list}}
-#' of \code{\link[base]{vector}}s (only used if \code{x} is  \code{\link[base]{vector}}).
-#' @param as.tibble logical.  If \code{TRUE} the output class will be set to a
-#' \pkg{tibble}, otherwise a \code{\link[data.table]{data.table}}.  Default
-#' checks \code{getOption("tibble.out")} as a logical.  If this is \code{NULL}
-#' the default \code{\link[textshape]{tibble_output}} will set \code{as.tibble}
-#' to \code{TRUE} if \pkg{dplyr} is loaded.  Otherwise, the output will be a
-#' \code{\link[data.table]{data.table}}.
+#' of \code{\link[base]{vector}}s (only used if \code{x} is \code{\link[base]{vector}}).
+#' @param content.attribute.name The name to use for the column created from the
+#' \code{\link[base]{list}} of names given to the \code{\link[base]{vector}}s
+#' (only used if \code{x} is named \code{\link[base]{vector}}).
 #' @param \ldots Ignored.
 #' @return Returns a \code{\link[data.table]{data.table}} with the \code{\link[base]{names}}
 #' from the \code{\link[base]{list}} as an \code{id} column.
@@ -24,6 +21,17 @@
 #' tidy_list(list(p=1:500, r=letters))
 #' tidy_list(list(p=mtcars, r=mtcars, z=mtcars, d=mtcars))
 #'
+#' x <- list(
+#'     a = setNames(c(1:4), LETTERS[1:4]),
+#'     b = setNames(c(7:9), LETTERS[7:9]),
+#'     c = setNames(c(10:15), LETTERS[10:15]),
+#'     d = c(x=4, y=6, 4),
+#'     e = setNames(1:10, sample(state.abb, 10, TRUE)),
+#'     f = setNames(1:10, sample(month.abb, 10, TRUE))
+#' )
+#'
+#' tidy_list(x)
+#'
 #' \dontrun{
 #' ## 2015 Vice-Presidential Debates Example
 #' if (!require("pacman")) install.packages("pacman")
@@ -48,14 +56,14 @@
 #'     textshape::tidy_list("location")
 #' }
 tidy_list <- function(x, id.name= "id", content.name = "content",
-    as.tibble = tibble_output(), ...){
+    content.attribute.name = 'attribute', ...){
 
     if (is.data.frame(x[[1]])){
-        if_tibble(tidy_list_df(x = x, id.name = id.name), as.tibble = as.tibble)
+        tidy_list_df(x = x, id.name = id.name)
     } else {
 
         if (is.vector(x[[1]])){
-            if_tibble(tidy_list_vector(x = x, id.name = id.name, content.name = content.name), as.tibble = as.tibble)
+            tidy_list_vector(x = x, id.name = id.name, content.name = content.name)
         } else {
             stop("`x` must be a list of `data.frame`s or `vector`s")
         }
@@ -65,8 +73,8 @@ tidy_list <- function(x, id.name= "id", content.name = "content",
 
 
 tidy_list_df <- function (x, id.name = "id"){
-    if (is.null(x)) {
-        names(x) <- paste0("L", pad(1:length(x)))
+    if (is.null(names(x))) {
+        names(x) <- seq_along(x)
     }
     list.names <- rep(names(x), sapply(x, nrow))
     out <- data.frame(list.names, do.call(rbind, x),
@@ -75,19 +83,30 @@ tidy_list_df <- function (x, id.name = "id"){
     data.table::data.table(out)
 }
 
-tidy_list_vector <- function(x, id.name= "id", content.name = "content"){
+tidy_list_vector <- function(x, id.name = "id",
+    content.attribute.name = 'attribute', content.name = "content"){
+
     if (is.null(names(x))) {
         names(x) <- seq_along(x)
     }
-    dat <- data.frame(
-        rep(names(x), sapply(x, length)),
-        unlist(x, use.names = FALSE),
-        stringsAsFactors = FALSE,
-        check.names = FALSE,
-        row.names = NULL
-    )
-    colnames(dat) <- c(id.name, content.name)
-    data.table::data.table(dat)
+
+    if (all(!sapply(x, function(y) is.null(names(y))))){
+
+        tidy_list(lapply(x, tidy_vector, content.attribute.name , content.name ), id.name)
+
+    } else {
+
+        dat <- data.frame(
+            rep(names(x), sapply(x, length)),
+            unlist(x, use.names = FALSE),
+            stringsAsFactors = FALSE,
+            check.names = FALSE,
+            row.names = NULL
+        )
+        colnames(dat) <- c(id.name, content.name)
+        data.table::data.table(dat)
+
+    }
 }
 
 
